/*   File: utilities.h

     Various utility functions used by the program 'cpParam'.

     Author: Warwick Tucker <warwick@math.uu.se>
     Latest edit: Thu Oct 27 14:04:16 CEST 2005
*/

#ifndef __UTILITIES_H__
#define __UTILITIES_H__

#include <iostream>
#include <fstream>
#include <sstream>
#include <string>
#include <time.h>

#include "Constants.h"
#include "Interval.h"
#include "IntervalVector.h"
#include "IntervalMatrix.h"
#include "Functions.h"
#include "Matrix.h"
#include "Vector.h"
#include "aux/list.h"

using namespace std;

#define BOX INTERVAL_VECTOR
#define  IM INTERVAL_MATRIX

enum command {START_TIMING, SHOW_TIMING, STOP_TIMING};

void   clock(const command &cmd);
double uniformRnd(double min, double max);
double Diameter(const IM &M);
BOX    Hull(List<BOX> &boxList);
IM     Hull(List<IM> &imList);
VECTOR averageOfTheList(List<BOX> &boxList);
MATRIX averageOfTheList(List<IM> &matList);
void   widestElement(int &i, int &j, const IM &p);
int    widestElement(const BOX &p);
void   splitAndStore(const BOX &p, List<BOX> &ioList);
void   splitAndStore(const IM &p, List<IM> &ioList);
void   insertData(IM &dS, const IM &xVal, const IM &sVal, int run, int runs);
IM     getData(istream& inFile, int dim, int samp);
string int2string(int number);
void   readData(IM &dS, int dim, int samples, int runs, string dataDir);
void   getDataSlice(IM &dataSlice, const IM &dataSet, int comp);
bool   getArguments(int &Samp, int &Runs, int Dim, string dataDir);
void   prettyPrint(const MATRIX &p);
void   prettyPrint(const IM &p);
void   prettyPrint(const BOX &p);
void   prettyPrint(const VECTOR &p);

#endif // __UTILITIES_H__


